@@ -12,7 +12,7 @@
 
 
 PowData *
-PowFindData(char *data_name) {
+PowFindData(const char *data_name) {
   Tcl_HashEntry *entry_ptr;
   PowData *data_ptr;
 
