@@ -280,7 +280,7 @@ PowCurveCoords(interp, canvas, itemPtr, objc, objv)
     PowCurveItem *powCurvePtr = (PowCurveItem *) itemPtr;
     double *pCoordPtr, *lCoordPtr;
     /*From the old PowProcessCurve command */
-    char **bboxptr;
+    const char **bboxptr;
     double x0 , x1, y0, y1;
     double rx0 , rx1, ry0, ry1, ry, rx;
     int n, xoff, yoff, xeoff, yeoff;
@@ -1727,7 +1727,7 @@ PowCurveInsert(canvas, itemPtr, beforeThis, string)
     Tk_Item *itemPtr;		/* PowCurve item to be modified. */
     int beforeThis;		/* Index before which new coordinates
 				 * are to be inserted. */
-    char *string;		/* New coordinates to be inserted. */
+    Tcl_Obj *string;		/* New coordinates to be inserted. */
 {
     PowCurveItem *powCurvePtr = (PowCurveItem *) itemPtr;
     int length, argc, i;
@@ -1739,10 +1739,31 @@ PowCurveInsert(canvas, itemPtr, beforeThis, string)
 	state = ((TkCanvas *)canvas)->canvas_state;
     }
 
-    if(!string || !*string) {
+    /*
+     * Pan Chai - 03-15-2024                                                         
+     *     Update variable "string" from char * to Tcl_Obj * requires                
+     *     calling Tcl_GetStringFromObj to get string value.                                             
+     *                                                                               
+     *     Orginal Statement                                                         
+     *                                                                               
+     *        if(!string || !*string) {
+     *                                                                               */
+
+    if(!Tcl_GetStringFromObj( string, NULL ) || !*Tcl_GetStringFromObj( string, NULL )) {
 	return;
     }
-    if ((Tcl_SplitList(((TkCanvas *)canvas)->interp, string, &argc, &argv) != TCL_OK)
+
+    /*
+     * Pan Chai - 03-15-2024                                                         
+     *     Update variable "string" from char * to Tcl_Obj * requires                
+     *     calling Tcl_GetStringFromObj to get string value.                                             
+     *                                                                               
+     *     Orginal Statement                                                         
+     *                                                                               
+     *        if ((Tcl_SplitList(((TkCanvas *)canvas)->interp, string, &argc, &argv) != TCL_OK)
+     *                                                                                           */
+
+    if ((Tcl_SplitList(((TkCanvas *)canvas)->interp, Tcl_GetStringFromObj( string, NULL) , &argc, &argv) != TCL_OK)
 	    || argv == NULL || !argc || argc&1) {
 	Tcl_ResetResult(((TkCanvas *)canvas)->interp);
 	if (argv != NULL) {
@@ -2132,7 +2153,7 @@ GetPowCurveIndex(interp, canvas, itemPtr, string, indexPtr)
     Tk_Canvas canvas;		/* Canvas containing item. */
     Tk_Item *itemPtr;		/* Item for which the index is being
 				 * specified. */
-    char *string;		/* Specification of a particular coord
+    Tcl_Obj *string;		/* Specification of a particular coord
 				 * in itemPtr's powCurve. */
     int *indexPtr;		/* Where to store converted index. */
 {
@@ -2144,7 +2165,18 @@ GetPowCurveIndex(interp, canvas, itemPtr, string, indexPtr)
      */
     
     Tcl_SetResult(interp, (char *) NULL, TCL_STATIC);
-    Tcl_AppendResult(interp, "bad index \"", string, "\"",
+
+    /*
+     * Pan Chai - 03-15-2024                                                         
+     *     Update variable "string" from char * to Tcl_Obj * requires                
+     *     calling Tcl_GetStringFromObj to get string value.
+     *                                                                               
+     *     Orginal Statement                                                         
+     *                                                                               
+     *        Tcl_AppendResult(interp, "bad index \"", string, "\"", (char *) NULL); 
+     *                                                                               */
+  
+    Tcl_AppendResult(interp, "bad index \"", Tcl_GetStringFromObj( string, NULL ), "\"",
 		     (char *) NULL);
     return TCL_ERROR;
 }
