@@ -3,7 +3,20 @@
 extern XColor	 lut_colorcell_defs[256];
 extern PictColorTable *PowColorTable;
 
-int PowSetupColormap(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[] ) {
+/*
+ * Pan Chai - 03-15-2024
+ *
+ *     The following functions were updated its parameter argv[] from char * to const char *
+ *
+ *         PowSetupColormap
+ *         PowSetupPhotoImages
+ *         PowTestColormap
+ *         PowPhotoColorTable
+ *         PowReditherPhotoBlock
+ *                          
+ */        
+
+int PowSetupColormap(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[] ) {
   /* This routine creates a toplevel window with a colormap for that
      window which has the specified number of cells free in addition to those
      needed by POW.  If force_cmap is non-zero:
@@ -260,7 +273,7 @@ int PowSetupColormap(ClientData clientData, Tcl_Interp *interp, int argc, char *
 
 
 
-int PowTestColormap(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[] ) {
+int PowTestColormap(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[] ) {
   /* This routine returns the number of free colors in the colormap of
      the specified window */
 #if defined(__WIN32__) || defined(macintosh)
@@ -332,7 +345,7 @@ int PowTestColormap(ClientData clientData, Tcl_Interp *interp, int argc, char *a
 }
 
 
-int PowSetupPhotoImages(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[] ) {
+int PowSetupPhotoImages(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[] ) {
   int ncolors=256;
   int lut_start=0;
   int color_def;
@@ -457,7 +470,7 @@ int PowGetHisto(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowPhotoColorTable (ClientData clientData, Tcl_Interp *interp,
-			int argc, char *argv[])
+			int argc, const char *argv[])
 {
   void (*f)(Display *display,Colormap cmap,
 	    int ncolors,int lut_start,char overlay,
@@ -786,7 +799,7 @@ int PowImageScale( ClientData clientData, Tcl_Interp *interp,
 }
 
 
-int PowReditherPhotoBlock (ClientData clientData, Tcl_Interp *interp, int argc, char *argv[] ) {
+int PowReditherPhotoBlock (ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[] ) {
   PowImage *image_instance;
   Tk_PhotoHandle photo_handle;
   Tk_PhotoImageBlock photo_block;
