@@ -18,11 +18,56 @@ typedef struct {
    double x,y;
 } Point;
 
+/*
+ * Pan Chai - 03-15-2024
+ *
+ *     The following functions were updated its parameter argv[] from char * to const char *
+ *
+ *         PowGetImageOrigin
+ *         PowGetImageOtherend
+ *         PowGetImageUnits
+ *         PowCreateData_Tcl
+ *         PowCloneData
+ *         PowFindData_Tcl
+ *         PowRegisterData_Tcl
+ *         PowDestroyData_Tcl
+ *         PowDestroyImage_Tcl
+ *         PowDestroyVector_Tcl
+ *         PowDestroyCurve_Tcl
+ *         PowDestroyGraph_Tcl
+ *         PowCreateDataFromList
+ *         PowCreateCurve_Tcl
+ *         PowCreateHisto_Tcl
+ *         PowCreateVector_Tcl
+ *         PowCreateVectorEN_Tcl
+ *         PowCreateImage_Tcl
+ *         PowCreateGraph_Tcl
+ *         PowFindCurvesMinMax_Tcl
+ *         PowFetchDataLength
+ *
+ *         PowFetchCurveInfoHash
+ *         PowFetchVectorInfoHash
+ *         PowFetchImageInfoHash
+ *         PowSetGraphMagstep
+ *         PowProcessCurve
+ *         PowListGraphs
+ *         PowListCurves
+ *         PowListImages
+ *         PowListVectors
+ *         PowListData
+ *         PowCleanUp
+ *         PowPutZoomedBlock
+ *         PowGetRegionStatistics
+ *         PowCreateDataFlip_Tcl
+ *         PowCreateCurveFlip_Tcl
+ *                                        
+ */
+
 extern int Pow_Allocated;
 extern PictColorTable *PowColorTable;
 
 int PowCleanUp(ClientData clientData, Tcl_Interp *interp, 
-	       int argc, char *argv[]) {
+	       int argc, const char *argv[]) {
 #if !(defined(__WIN32__) || defined(macintosh))
     /*
     Tcl_HashEntry *entry_ptr;
@@ -74,7 +119,7 @@ int PowCleanUp(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowListGraphs(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   Tcl_HashEntry *entry_ptr;
   Tcl_HashSearch search;
   if (argc == 2) {
@@ -95,7 +140,7 @@ int PowListGraphs(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowListCurves(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   Tcl_HashEntry *entry_ptr;
   Tcl_HashSearch search;
   if (argc == 2) {
@@ -116,7 +161,7 @@ int PowListCurves(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowListImages(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   Tcl_HashEntry *entry_ptr;
   Tcl_HashSearch search;
   if (argc == 2) {
@@ -137,7 +182,7 @@ int PowListImages(ClientData clientData, Tcl_Interp *interp,
 }
 		      
 int PowListVectors(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   Tcl_HashEntry *entry_ptr;
   Tcl_HashSearch search;
   if (argc == 2) {
@@ -158,7 +203,7 @@ int PowListVectors(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowListData(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   Tcl_HashEntry *entry_ptr;
   Tcl_HashSearch search;
   if (argc == 2) {
@@ -180,7 +225,7 @@ int PowListData(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowProcessCurve(ClientData clientData, Tcl_Interp *interp, 
-		    int argc, char *argv[]) {
+		    int argc, const char *argv[]) {
   /* calculate the list of points for powPlotCurve */
   const char **bboxptr;
   const char **rbboxptr;
@@ -402,7 +447,7 @@ int PowProcessCurve(ClientData clientData, Tcl_Interp *interp,
 
   
 int PowSetGraphMagstep(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   int status = TCL_OK;
   PowGraph *graph_ptr;
   if(argc != 4) {
@@ -422,9 +467,10 @@ int PowSetGraphMagstep(ClientData clientData, Tcl_Interp *interp,
   
 
 int PowGetImageOrigin(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   PowImage *image_ptr;
   char longStr[1024];
+
   if(argc != 3) {
     Tcl_SetResult(interp, "wrong # args", TCL_VOLATILE);
     return TCL_ERROR;
@@ -449,9 +495,10 @@ int PowGetImageOrigin(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowGetImageOtherend(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   PowImage *image_ptr;
   char longStr[1024];
+
   if(argc != 3) {
     Tcl_SetResult(interp, "wrong # args", TCL_VOLATILE);
     return TCL_ERROR;
@@ -477,9 +524,10 @@ int PowGetImageOtherend(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowGetImageUnits(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   PowImage *image_ptr;
   char longStr[1024];
+
   if(argc != 3) {
     Tcl_SetResult(interp, "wrong # args", TCL_VOLATILE);
     return TCL_ERROR;
@@ -608,7 +656,7 @@ int PowTestMacMemory( ClientData clientData, Tcl_Interp *interp,
 
 
 int PowPutZoomedBlock(ClientData clientData, Tcl_Interp *interp, 
-		      int argc, char *argv[]) {
+		      int argc, const char *argv[]) {
   /* calls the VISU routine Tk_PictPutZoomedBlock or
      Tk_PhotoPutZoomedBlock*/
   /* this is a low level routine */
@@ -731,7 +779,7 @@ int PowPutZoomedBlock(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowDestroyData_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powDestroyData data_name*/
   int status=0;
 
@@ -751,7 +799,7 @@ int PowDestroyData_Tcl(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowCloneData(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /*usage: powCloneData new_data_name old_data_name ?offset? ?length? ?copy?*/
 
   int data_type,length,status = 0;
@@ -820,7 +868,7 @@ int PowCloneData(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowCreateDataFlip_Tcl(ClientData clientData, Tcl_Interp *interp,
-                          int argc, char *argv[]) {
+                          int argc, const char *argv[]) {
   /* this is the TCL wrapper for the PowCreateDataFlip routine.  */
   /* the pointer to the data should be converted using sprintf(PTRFORMAT,pointer) */
     
@@ -849,7 +897,7 @@ int PowCreateDataFlip_Tcl(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowCreateCurveFlip_Tcl(ClientData clientData, Tcl_Interp *interp,
-                          int argc, char *argv[]) {
+                          int argc, const char *argv[]) {
   /* this is the TCL wrapper for the PowCreateCurveFlip routine.  */
   /* the pointer to the data should be converted using sprintf(PTRFORMAT,pointer) */
     
@@ -902,7 +950,7 @@ int PowCreateCurveFlip_Tcl(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowCreateData_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powCreateData data_name data_pointer data_type length ?copy?  */
   /* this is the TCL wrapper for the PowCreateData routine.  */
   /* the pointer to the data should be converted using sprintf(PTRFORMAT,pointer) */
@@ -957,7 +1005,7 @@ int PowCreateData_Tcl(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowFindData_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /*This is a wrapper on PowFindData to see if image data exists */
   PowData *powdatabuff;
 
@@ -976,7 +1024,7 @@ int PowFindData_Tcl(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowRegisterData_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /*This is for people who create their PowData objects outside of pow */
   /*(e.g. users of the LHEA orbit libraries) but then want to import them */
   /*into POW. */
@@ -1005,7 +1053,7 @@ int PowRegisterData_Tcl(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowDestroyImage_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powDestroyImage image_name*/
   int status=0;
 
@@ -1026,7 +1074,7 @@ int PowDestroyImage_Tcl(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowCreateImage_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powCreateImage image_name data_name xoffset yoffset\  */
   /*        width height xorigin xinc yorigin yinc xunits yunits zunits */
   /* this is the TCL wrapper for the PowCreateImage routine.  */
@@ -1091,7 +1139,7 @@ int PowCreateImage_Tcl(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowDestroyVector_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powDestroyVector vector_name*/
   int status=0;
 
@@ -1112,7 +1160,7 @@ int PowDestroyVector_Tcl(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowCreateVector_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powCreateVector vector_name data_name offset length\  */
   /*        units */
   /* this is the TCL wrapper for the PowCreateVector routine.  */
@@ -1146,7 +1194,7 @@ int PowCreateVector_Tcl(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowDestroyCurve_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powDestroyCurve curve_name*/
   int status=0;
 
@@ -1168,7 +1216,7 @@ int PowDestroyCurve_Tcl(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowCreateCurve_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powCreateCurve curve_name x_vector x_error y_vector y_error\  */
   /*        <z_vector z_error> */
   /* this is the TCL wrapper for the PowCreateVector routine.  */
@@ -1205,7 +1253,7 @@ int PowCreateCurve_Tcl(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowCreateVectorEN_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powCreateVectorEN vector_name data_name length start
   increment units */
   /* this is the TCL wrapper for the PowCreateVector routine.  */
@@ -1268,7 +1316,7 @@ int PowDataPtr_Tcl(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowCreateHisto_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powCreateHisto histo_name x_vector y_vector */
   /* this is the TCL wrapper for the PowCreateHisto routine.  */
   
@@ -1292,7 +1340,7 @@ int PowCreateHisto_Tcl(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowDestroyGraph_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powDestroyGraph graph_name*/
   int status=0;
 
@@ -1313,7 +1361,7 @@ int PowDestroyGraph_Tcl(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowCreateGraph_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powCreateGraph graph_name curves images xunits yunits xlabel\  */
   /*        ylabel xdimdisp ydimdisp <xmin ymin xmax ymax> */
   /* this is the TCL wrapper for the PowCreateImage routine.  */
@@ -1505,7 +1553,7 @@ fflush(stdout);
 }
 
 int PowFetchCurveInfoHash(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powFetchVectorHash curvename */
   /* used by the vector edit window to fetch component vector names */
   PowCurve *curve_ptr;
@@ -1551,7 +1599,7 @@ int PowFetchCurveInfoHash(ClientData clientData, Tcl_Interp *interp,
 }
   
 int PowFetchDataLength(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powFetchDataLength data_name */
   /* used by the data edit window to fetch data structure fields */
   PowData *data_ptr;
@@ -1609,7 +1657,7 @@ int PowExprDataInfo(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowFetchVectorInfoHash(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powFetchVectorInfoHash vector_name */
   /* used by the vector edit window to fetch vector structure fields */
   PowVector *vector_ptr;
@@ -1640,7 +1688,7 @@ int PowFetchVectorInfoHash(ClientData clientData, Tcl_Interp *interp,
 
 
 int PowFetchImageInfoHash(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powFetchImageInfoHash image_name */
   /* used by the image edit window to fetch image structure fields */
   PowImage *image_ptr;
@@ -1698,7 +1746,7 @@ int PowFetchImageInfoHash(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowFindCurvesMinMax_Tcl(ClientData clientData, Tcl_Interp *interp, 
-		   int argc, char *argv[]) {
+		   int argc, const char *argv[]) {
   /* usage: powFindCurveMinMax curves axis */
   /* this is the TCL wrapper for the PowFindCurvesMinMax routine.  */
   double min, max;
@@ -1970,7 +2018,7 @@ int PowCreateDataFromPtr(ClientData clientData, Tcl_Interp *interp,
 }
 
 int PowCreateDataFromList(ClientData clientData, Tcl_Interp *interp, 
-			  int argc, char *argv[]) {
+			  int argc, const char *argv[]) {
   /* usage: powCreateDataFromList data_name list_o_data*/
   int largc;
   const char **largv, **counter;
@@ -2816,7 +2864,7 @@ int PowWCSisSwapped( ClientData clientData, Tcl_Interp *interp,
 
 /* Get the centroid and flux */
 int PowGetRegionStatistics( ClientData clientData, Tcl_Interp *interp, 
-                  int argc, char **argv )
+                  int argc, const char **argv )
 {
   char *imgName;
   PowImage *image_ptr;
