@@ -17,6 +17,16 @@
          Author: Peter D. Wilson, 12/97-1/98
 
 ************************************************************************/
+/*         
+ * Pan Chai - 03-15-2024
+ *
+ *     The following functions were updated its parameter argv[] from char * to const char *
+ *
+ *         PowDrawGridLines
+ *         PowCreateContour
+ *         PowGetTics
+ *
+ */
 #include "pow.h"
 
       /*****  Additional structures/data types  *****/
@@ -38,7 +48,7 @@ typedef struct {
       /*****  Function Prototypes in PowGrid.c  *****/
 
 int   PowDrawGridLines( ClientData clientData, Tcl_Interp *interp, 
-			int argc, char *argv[] );
+			int argc, const char *argv[] );
 int   CreateGridPts( PowGraph *graph, int zoomed, const char *graphType, int xCount, int yCount, 
                      Point BotLeft_real, Point BotLeft, Point TopRgt, GridPt **rtnGrid );
 int   GetTicks( int nGrid, GridPt Grid[], int useWCS, char *tickScal[2],
@@ -58,7 +68,7 @@ int GraphToCanv( PowGraph *graph, int zoomed, const char *graphType, int xCount,
 /*****************************************************************/
 
 int PowDrawGridLines(ClientData clientData, Tcl_Interp *interp, 
-		     int argc, char *argv[])
+		     int argc, const char *argv[])
 {
    char *gn, *canvas, *color, *dash;
    const char **list;
@@ -626,7 +636,7 @@ int GetTicks(int nGrid, GridPt Grid[], int useWCS, char *tickScal[2],
 }
 
 int PowGetTics(ClientData clientData, Tcl_Interp *interp, 
-	       int argc, char *argv[])
+	       int argc, const char *argv[])
 {
    double min, max, ticks[100];
    int nlabels, nFnd, i, loc;
@@ -1124,7 +1134,7 @@ int TraceContour ( Contours *Info, double cntr,
 
 
 int PowCreateContour(ClientData clientData, Tcl_Interp *interp, 
-		     int argc, char *argv[])
+		     int argc, const char *argv[])
 {
    char *contour, *image;
    double *imgData, levels[MAXCONTOURS], *lvlPtr;
