@@ -62,7 +62,7 @@ int FillinWCSStructure ( WCSdata *WCS )
 
    ctrl = 2;
 
-   if (status = wcspih(HDRstring, HDRcnt, relax, ctrl, &nreject, &nwcs, &(WCS->wcs))) {
+   if ((status = wcspih(HDRstring, HDRcnt, relax, ctrl, &nreject, &nwcs, &(WCS->wcs)))) {
       char errormsg[512];
       sprintf(errormsg, "Can't construct WCS information: %s", WCSpih_Message[status]);
       Tcl_SetResult(interp, errormsg ,TCL_VOLATILE);
