@@ -215,10 +215,10 @@ void PowCreateGraph_internal(char *, char *, char *, char *, char *, char *,
 void PowDestroyGraph(char *graph_name, int *status);
 
 void PowCreateDataFlip(char *, char *, int *, int *, int *);
-int PowCreateDataFlip_Tcl(ClientData, Tcl_Interp *, int, char **);
+int PowCreateDataFlip_Tcl(ClientData, Tcl_Interp *, int, const char **);
 
 void PowCreateCurveFlip(char *, char *, int *);
-int PowCreateCurveFlip_Tcl(ClientData, Tcl_Interp *, int, char **);
+int PowCreateCurveFlip_Tcl(ClientData, Tcl_Interp *, int, const char **);
 
 void PowInitWCS( WCSdata *WCS, int n );
 int FillinWCSStructure (WCSdata *WCS);
@@ -275,53 +275,53 @@ int PowWCSInitImage(ClientData , Tcl_Interp *, int , Tcl_Obj *const []);
 int PowWCSInitCurve(ClientData , Tcl_Interp *, int , Tcl_Obj *const []);
 int PowWCSexists(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowWCSisSwapped(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
-int PowGetImageOrigin(ClientData , Tcl_Interp *, int , char **);
-int PowGetImageOtherend(ClientData , Tcl_Interp *, int , char **);
-int PowGetImageUnits(ClientData , Tcl_Interp *, int , char **);
-int PowCreateData_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowCloneData(ClientData, Tcl_Interp *, int, char **);
-int PowFindData_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowRegisterData_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowDestroyData_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowDestroyImage_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowDestroyVector_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowDestroyCurve_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowDestroyGraph_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowDestroyImage_Tcl(ClientData, Tcl_Interp *, int, char **);
+int PowGetImageOrigin(ClientData , Tcl_Interp *, int , const char **);
+int PowGetImageOtherend(ClientData , Tcl_Interp *, int , const char **);
+int PowGetImageUnits(ClientData , Tcl_Interp *, int , const char **);
+int PowCreateData_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowCloneData(ClientData, Tcl_Interp *, int, const char **);
+int PowFindData_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowRegisterData_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowDestroyData_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowDestroyImage_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowDestroyVector_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowDestroyCurve_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowDestroyGraph_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowDestroyImage_Tcl(ClientData, Tcl_Interp *, int, const char **);
 int PowCreateDataFromBuffer(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowCreateDataFromChannel(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowCreateDataFromPtr(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowCreateStrFromPtr(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
-int PowCreateDataFromList(ClientData, Tcl_Interp *, int, char **);
-int PowCreateCurve_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowCreateHisto_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowCreateVector_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowCreateVectorEN_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowCreateImage_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowCreateGraph_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowFindCurvesMinMax_Tcl(ClientData, Tcl_Interp *, int, char **);
-int PowFetchDataLength(ClientData, Tcl_Interp *, int, char **);
+int PowCreateDataFromList(ClientData, Tcl_Interp *, int, const char **);
+int PowCreateCurve_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowCreateHisto_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowCreateVector_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowCreateVectorEN_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowCreateImage_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowCreateGraph_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowFindCurvesMinMax_Tcl(ClientData, Tcl_Interp *, int, const char **);
+int PowFetchDataLength(ClientData, Tcl_Interp *, int, const char **);
 int PowExprDataInfo(ClientData, Tcl_Interp *, int, Tcl_Obj *const [] );
 int PowDataPtr_Tcl(ClientData, Tcl_Interp *, int, Tcl_Obj *const [] );
-int PowFetchCurveInfoHash(ClientData, Tcl_Interp *, int, char **);
-int PowFetchVectorInfoHash(ClientData, Tcl_Interp *, int, char **);
-int PowFetchImageInfoHash(ClientData, Tcl_Interp *, int, char **);
-int PowSetGraphMagstep(ClientData, Tcl_Interp *, int, char **);
-int PowProcessCurve(ClientData, Tcl_Interp *, int, char **);
-int PowListGraphs(ClientData, Tcl_Interp *, int, char **);
-int PowListCurves(ClientData, Tcl_Interp *, int, char **);
-int PowListImages(ClientData, Tcl_Interp *, int, char **);
-int PowListVectors(ClientData, Tcl_Interp *, int, char **);
-int PowListData(ClientData, Tcl_Interp *, int, char **);
-int PowCleanUp(ClientData, Tcl_Interp *, int, char **);
-int PowSetupColormap(ClientData, Tcl_Interp *, int, char **);
-int PowSetupPhotoImages(ClientData, Tcl_Interp *, int, char **);
-int PowTestColormap(ClientData, Tcl_Interp *, int, char **);
+int PowFetchCurveInfoHash(ClientData, Tcl_Interp *, int, const char **);
+int PowFetchVectorInfoHash(ClientData, Tcl_Interp *, int, const char **);
+int PowFetchImageInfoHash(ClientData, Tcl_Interp *, int, const char **);
+int PowSetGraphMagstep(ClientData, Tcl_Interp *, int, const char **);
+int PowProcessCurve(ClientData, Tcl_Interp *, int, const char **);
+int PowListGraphs(ClientData, Tcl_Interp *, int, const char **);
+int PowListCurves(ClientData, Tcl_Interp *, int, const char **);
+int PowListImages(ClientData, Tcl_Interp *, int, const char **);
+int PowListVectors(ClientData, Tcl_Interp *, int, const char **);
+int PowListData(ClientData, Tcl_Interp *, int, const char **);
+int PowCleanUp(ClientData, Tcl_Interp *, int, const char **);
+int PowSetupColormap(ClientData, Tcl_Interp *, int, const char **);
+int PowSetupPhotoImages(ClientData, Tcl_Interp *, int, const char **);
+int PowTestColormap(ClientData, Tcl_Interp *, int, const char **);
 int PowPhotoCmapStretch(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
-int PowPhotoColorTable(ClientData, Tcl_Interp *, int, char **);
+int PowPhotoColorTable(ClientData, Tcl_Interp *, int, const char **);
 int PowTestMacMemory(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
-int PowPutZoomedBlock(ClientData, Tcl_Interp *, int, char **);
-int PowReditherPhotoBlock(ClientData, Tcl_Interp *, int, char **);
+int PowPutZoomedBlock(ClientData, Tcl_Interp *, int, const char **);
+int PowReditherPhotoBlock(ClientData, Tcl_Interp *, int, const char **);
 int PowImageScale(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowGetHisto(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowGetImageZ(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
@@ -337,11 +337,11 @@ int PowResetWcsStructure(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowGraphVToPixelV(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowPixelVToGraphV(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
 int PowGetImageClipbox(ClientData, Tcl_Interp *, int, Tcl_Obj *const []);
-int PowDrawGridLines(ClientData, Tcl_Interp *, int, char **);
-int PowCreateContour(ClientData, Tcl_Interp *, int, char **);
-int PowGetTics(ClientData, Tcl_Interp *, int, char **);
+int PowDrawGridLines(ClientData, Tcl_Interp *, int, const char **);
+int PowCreateContour(ClientData, Tcl_Interp *, int, const char **);
+int PowGetTics(ClientData, Tcl_Interp *, int, const char **);
 int PowTestImage(ClientData, Tcl_Interp *, int, Tcl_Obj *const[]);
-int PowGetRegionStatistics( ClientData, Tcl_Interp *, int , char ** );
+int PowGetRegionStatistics( ClientData, Tcl_Interp *, int , const char ** );
 
 int pow_worldpos(double, double,
                  double [], double [], double [][MAX_WCS_DIMS], char *,
@@ -438,14 +438,14 @@ extern Tk_ItemType tkPowCurveType;
 			    int x, int y, int width, int height));
  int		GetPowCurveIndex _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Canvas canvas, Tk_Item *itemPtr,
-			    char *indexString, int *indexPtr));
+			    Tcl_Obj *indexString, int *indexPtr));
  int		PowCurveCoords _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Canvas canvas, Tk_Item *itemPtr,
 			    int objc, Tcl_Obj *CONST objv[]));
  void		PowCurveDeleteCoords _ANSI_ARGS_((Tk_Canvas canvas,
 			    Tk_Item *itemPtr, int first, int last));
  void		PowCurveInsert _ANSI_ARGS_((Tk_Canvas canvas,
-			    Tk_Item *itemPtr, int beforeThis, char *string));
+			    Tk_Item *itemPtr, int beforeThis, Tcl_Obj *string));
  int		PowCurveToArea _ANSI_ARGS_((Tk_Canvas canvas,
 			    Tk_Item *itemPtr, double *rectPtr));
  double		PowCurveToPoint _ANSI_ARGS_((Tk_Canvas canvas,
